Welcome to dogpile.core’s documentation! — dogpile.core 0.4.0 documentation

### Navigation

- index
- next |
- dogpile.core 0.4.0 documentation »

# Welcome to dogpile.core’s documentation!

dogpile.core provides the dogpile lock, one which allows a single thread or process to generate an expensive resource while other threads/processes use the “old” value, until the “new” value is ready.

dogpile.core is at the core of the dogpile.cache package which provides for a basic cache API and sample backends based on the dogpile concept.

- Front Matter
  - Project Homepage
  - Installation
  - Community
  - Bugs
- Usage Guide
  - Do I Need to Learn the dogpile.core API Directly?
  - Rudimentary Usage
  - Using dogpile.core for Caching
  - Using a File or Distributed Lock with Dogpile
- API
  - Dogpile
  - Utilities
  - Legacy API

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- dogpile.core 0.4.0 documentation »